// (C) 2001-2019 Intel Corporation. All rights reserved.
// Your use of Intel Corporation's design tools, logic functions and other 
// software and tools, and its AMPP partner logic functions, and any output 
// files from any of the foregoing (including device programming or simulation 
// files), and any associated documentation or information are expressly subject 
// to the terms and conditions of the Intel Program License Subscription 
// Agreement, Intel FPGA IP License Agreement, or other applicable 
// license agreement, including, without limitation, that your use is for the 
// sole purpose of programming logic devices manufactured by Intel and sold by 
// Intel or its authorized distributors.  Please refer to the applicable 
// agreement for further details.


`timescale 1ns/1ps

module intel_pcie_descriptor_storage_fifo #(

  parameter DESC_DATA_WIDTH = 160,
  parameter PFNUM_WIDTH = 1,
  parameter VFNUM_WIDTH = 1,
  parameter DESC_BE_WIDTH = DESC_DATA_WIDTH/32,
  parameter STORAGE_FIFO_DEPTH = 7

)
(
    input logic                                       clk,
    input logic                                       rst_n,

    input logic [DESC_DATA_WIDTH * 2 -1:0]            dma_s_wdata_i,
    input logic [DESC_BE_WIDTH * 2 -1:0]              dma_s_be_i,
    input logic                                       dma_s_write_i,

    input logic                                       ready_i,

    output logic [DESC_DATA_WIDTH-1:0]                desc_rdata_o,
    output logic                                      data_valid_o,
    output logic                                      full_o,
    output logic [STORAGE_FIFO_DEPTH+1:0]             fillcount_o


);


//logic                                rd_ptr, rd_ptr_r;
logic [STORAGE_FIFO_DEPTH:0]         rd_ptr,rd_ptr_r,rd_ptr_rr;
logic [STORAGE_FIFO_DEPTH-1:0]       wr_ptr;

logic [DESC_DATA_WIDTH * 2 -1:0]     wdata_s1;
logic [DESC_DATA_WIDTH -1:0]         wdata_old;
logic [DESC_DATA_WIDTH * 2 -1:0]     wdata_wire;
logic [DESC_DATA_WIDTH * 2 -1:0]     wdata_r;
logic [DESC_DATA_WIDTH * 2 -1:0]     rdata_wire;
logic [DESC_BE_WIDTH *2 -1:0]        dw_write;
logic [DESC_BE_WIDTH *2 -1:0]        dw_write_r;
logic [DESC_BE_WIDTH *2 -1:0]        dw_write_2r,dw_write_3r;
logic [DESC_BE_WIDTH -1:0]           dw_write_old;


logic                             w_lsb_next;
logic                             w_msb_next;
logic                             w_m_to_l;
logic                             w_m_to_m;
logic                             w_256;
logic                             w_512;
logic                             w_512_old;
logic                             fill_less_than4;
logic                             empty;
logic                             full;
logic                             ready_r;
logic                             dma_s_write;
logic read_req, read_req_r, read_req_rr;


  assign w_256 = dma_s_be_i[DESC_BE_WIDTH - 1];
  assign w_512 = dma_s_be_i[DESC_BE_WIDTH * 2 -1];
  assign full = fillcount_o[STORAGE_FIFO_DEPTH+1];

  assign read_req = !empty & ready_i;

  assign wdata_wire[DESC_DATA_WIDTH*2-1:DESC_DATA_WIDTH] = w_m_to_m ? wdata_s1 [DESC_DATA_WIDTH*2-1:DESC_DATA_WIDTH] : wdata_s1[DESC_DATA_WIDTH-1:0];
  assign wdata_wire[DESC_DATA_WIDTH-1:0] = w_m_to_l ? wdata_old : wdata_s1[DESC_DATA_WIDTH-1:0];

  always_ff @(posedge clk) begin
    wdata_s1     <= dma_s_wdata_i;
    wdata_old    <= wdata_s1[DESC_DATA_WIDTH*2-1:DESC_DATA_WIDTH];
    wdata_r      <= wdata_wire;
    desc_rdata_o <= rd_ptr_rr[0] ?  rdata_wire[DESC_DATA_WIDTH*2-1:DESC_DATA_WIDTH]: rdata_wire[DESC_DATA_WIDTH-1:0];
  end

  always_ff @(posedge clk) begin
    if (!rst_n) begin
      ready_r      <= '0;
      read_req_r   <= '0;
      read_req_rr  <= '0;
      data_valid_o <= '0;
    end else begin
      ready_r      <= ready_i;
      read_req_r   <= read_req;
      read_req_rr   <= read_req_r;
      data_valid_o <= read_req_rr;
    end
  end

  always_ff @(posedge clk) begin
    if (!rst_n) begin
      w_lsb_next  <= 1'b1;
      w_msb_next  <= '0;
      w_m_to_l    <= '0;
      w_m_to_m    <= 1'b1;
      w_512_old   <= '0;
      dw_write    <= '0;
      dw_write_r  <= '0;
      dw_write_2r <= '0;
      dw_write_3r <= '0;
      dma_s_write <= '0;
      dw_write_old <= '0;
    end
    else begin
      w_512_old <= w_512;
      dw_write_old <= dma_s_be_i[DESC_BE_WIDTH *2-1:DESC_BE_WIDTH];
      dw_write_r   <= dw_write;
      dw_write_2r  <= dw_write_r;
      dw_write_3r  <= dw_write_2r;
      dma_s_write <= dma_s_write_i; //YQY
      if (dma_s_write_i & w_256 & !w_512) begin
        w_lsb_next <= !w_lsb_next;
        w_msb_next <= !w_msb_next;
      end
      if (w_lsb_next & !w_msb_next) begin
        w_m_to_l    <= '0;
        w_m_to_m    <= 1'b1;
        dw_write    <= dma_s_be_i;
      end
      if (!w_lsb_next & w_msb_next) begin
        w_m_to_l    <= 1'b1;
        w_m_to_m    <= '0;
        dw_write    <= {dma_s_be_i[DESC_BE_WIDTH-1:0],dw_write_old};
      end
    end
  end

  always_ff @(posedge clk) begin
    if (!rst_n) begin
      rd_ptr <= '0;
      rd_ptr_r <= '0;
      rd_ptr_rr <= '0;
    end else begin
      rd_ptr_rr <= rd_ptr_r;
      rd_ptr_r <= rd_ptr;
      if (read_req) begin
        rd_ptr <=  rd_ptr +  1'b1;
      end 
      else begin
        rd_ptr <= rd_ptr;
      end
    end
  end
  
  always_ff @(posedge clk) begin
    if (!rst_n) begin
      wr_ptr <= '0;
    end
    else begin
      if (dw_write_r[DESC_BE_WIDTH * 2 - 1]) begin
        wr_ptr <= wr_ptr + 1'b1;
      end
      else begin
        wr_ptr <= wr_ptr;
      end
    end
  end
   
  
  genvar i;
  generate 
    for (i=0; i < (DESC_BE_WIDTH * 2); i=i+1 ) begin : data_msb_fifo_memory 
      altera_syncram  fifo_memory
      (
        .clock0         ( clk                              ),
        .wren_a         ( dw_write_r[i]                    ),
        .address_a      ( wr_ptr                           ),
        .data_a         ( wdata_r[32*i+31:32*i]            ),
        .rden_b         ( 1'b1                             ),
        .address_b      ( rd_ptr[STORAGE_FIFO_DEPTH:1]     ),
        .q_b            ( rdata_wire[32*i+31:32*i]         ),
        .aclr0          ( 1'b0                 ),
        .aclr1          ( 1'b0                 ),
        .sclr           ( 1'b0                 ), // Not used.
        .addressstall_a ( 1'b0                 ),
        .addressstall_b ( 1'b0                 ),
        .byteena_a      ( 1'b1                 ),
        .byteena_b      ( 1'b1                 ),
        .clock1         ( 1'b1                 ),
        .clocken0       ( 1'b1                 ),
        .clocken1       ( 1'b1                 ),
        .clocken2       ( 1'b1                 ),
        .clocken3       ( 1'b1                 ),
        .data_b         ( {32 {1'b1}}          ), // Not used.
        .eccencbypass   ( 1'b0                 ), // Not used.
        .eccencparity   ( 8'b0                 ), // Not used.
        .q_a            (                      ), // Not used.
        .rden_a         ( 1'b1                 ), // Not used.
        .wren_b         ( 1'b0                 ), // Not used.
        .eccstatus      (                      )  // Not used.
        );
      defparam
       fifo_memory.address_aclr_b              = "NONE",
       fifo_memory.address_reg_b               = "CLOCK0",
       fifo_memory.clock_enable_input_a        = "BYPASS",
       fifo_memory.clock_enable_input_b        = "BYPASS",
       fifo_memory.clock_enable_output_b       = "BYPASS",
       fifo_memory.enable_ecc                  = "FALSE",
       fifo_memory.ecc_pipeline_stage_enabled  = "FALSE",
       fifo_memory.intended_device_family      = "Stratix 10",
       fifo_memory.lpm_type                    = "altera_syncram",
       fifo_memory.maximum_depth               = 512,
       fifo_memory.numwords_a                  = 1<<STORAGE_FIFO_DEPTH,
       fifo_memory.numwords_b                  = 1<<STORAGE_FIFO_DEPTH,
       fifo_memory.operation_mode              = "DUAL_PORT",
       fifo_memory.outdata_aclr_b              = "NONE",
       fifo_memory.outdata_reg_b               = "CLOCK0",
       fifo_memory.power_up_uninitialized      = "FALSE",
       fifo_memory.ram_block_type              = "M20K",
       fifo_memory.widthad_a                   =  STORAGE_FIFO_DEPTH,
       fifo_memory.widthad_b                   =  STORAGE_FIFO_DEPTH,
       fifo_memory.width_a                     = 32,
       fifo_memory.width_b                     = 32,
       fifo_memory.width_byteena_a             = 1;
   end
  endgenerate 

  always_ff @(posedge clk) begin
    if (!rst_n) begin
      fillcount_o <= '0;
    end
    else begin
      fillcount_o <= fillcount_o; // Default - no read, no write OR one read, one write
      if ( read_req &  dw_write_3r[DESC_BE_WIDTH*2-1] &  dw_write_3r[DESC_BE_WIDTH-1])
        fillcount_o <= fillcount_o + 1'b1;  // One read, two write
      if (!read_req & (dw_write_3r[DESC_BE_WIDTH*2-1] ^  dw_write_3r[DESC_BE_WIDTH-1]))
        fillcount_o <= fillcount_o + 1'b1;  // No read, one write
      if (!read_req &  dw_write_3r[DESC_BE_WIDTH*2-1] &  dw_write_3r[DESC_BE_WIDTH-1])
        fillcount_o <= fillcount_o + 2'd2;  // No read, two write
      if ( read_req & !dw_write_3r[DESC_BE_WIDTH*2-1] & !dw_write_3r[DESC_BE_WIDTH-1])
        fillcount_o <= fillcount_o - 1'b1;  // One read, no write
    end
  end

  always_ff @(posedge clk) begin
    if (!rst_n) begin
      fill_less_than4          <= 1'b1;
      empty                   <= 1'b1;
      full_o                  <= 1'b0;
    end
    else begin
      fill_less_than4 <= (fillcount_o < 3'd4);
      empty <= fill_less_than4 & ((((fillcount_o[1:0] == 1) & read_req & !dw_write_3r[DESC_BE_WIDTH*2-1] & !dw_write_3r[DESC_BE_WIDTH-1])) | (fillcount_o[1:0] == 0));
      //full_o <= (&fillcount_o[STORAGE_FIFO_DEPTH:1] | full);
      full_o <= fillcount_o >= ((1 << STORAGE_FIFO_DEPTH) - 9);
    end
  end

endmodule