// (C) 2001-2019 Intel Corporation. All rights reserved.
// Your use of Intel Corporation's design tools, logic functions and other 
// software and tools, and its AMPP partner logic functions, and any output 
// files from any of the foregoing (including device programming or simulation 
// files), and any associated documentation or information are expressly subject 
// to the terms and conditions of the Intel Program License Subscription 
// Agreement, Intel FPGA IP License Agreement, or other applicable 
// license agreement, including, without limitation, that your use is for the 
// sole purpose of programming logic devices manufactured by Intel and sold by 
// Intel or its authorized distributors.  Please refer to the applicable 
// agreement for further details.




module  altera_pcie_s10_gen3x16_rx_st_if
 #(
    parameter pld_rx_parity_ena = "enable",
    parameter enable_sriov_hwtcl = 0
  )(
    input logic              clk500,
    input logic              rst,

    input logic              clk250,
    input logic              rst_clk250,
    input logic              usr_rst_clk250,

    //avst rx interface
    input logic              rx_st_ready_i,
    input logic              rx_st_sop_i,
    input logic              rx_st_eop_i,
    input logic [255:0]      rx_st_data_i,
    input logic [ 31:0]      rx_st_parity_i,
    input logic              rx_st_valid_i,
    input logic [ 2:0]       rx_st_bar_range_i,
    input logic [ 2:0]       rx_st_empty_i,
    input logic              rx_st_vf_active_i,
    input logic [1:0]        rx_st_func_num_i,
    input logic [10:0]       rx_st_vf_num_i,



    output logic [1:0]       rx_st_valid_o,
    output logic             rx_st_ready_o,
    output logic [1:0]       rx_st_sop_o,
    output logic [1:0]       rx_st_eop_o,
    output logic [256*2-1:0] rx_st_data_o,
    output logic [32*2-1:0]  rx_st_parity_o,
    output logic [3*2-1:0]   rx_st_bar_range_o,
    output logic [3*2-1:0]   rx_st_empty_o,
    output logic [1:0]       rx_st_vf_active_o,
    output logic [3:0]       rx_st_func_num_o,
    output logic [21:0]      rx_st_vf_num_o
    );

    localparam   par_sriov   = (pld_rx_parity_ena == "enable" && enable_sriov_hwtcl)? 1 : 0;
    localparam   only_sriov  = (pld_rx_parity_ena != "enable" && enable_sriov_hwtcl)? 1 : 0;
    localparam   only_par    = (pld_rx_parity_ena == "enable" && !enable_sriov_hwtcl)? 1 : 0;

    logic                    rx_st_ready;
    logic                    rx_st_vf_active_q,rx_st_vf_active_q1;
    logic [1:0]              rx_st_func_num_q,rx_st_func_num_q1;
    logic [10:0]             rx_st_vf_num_q,rx_st_vf_num_q1;

    logic                    rx_st_sop_q,rx_st_sop_q1;
    logic                    rx_st_eop_q,rx_st_eop_q1;
    logic [255:0]            rx_st_data_q,rx_st_data_q1;
    logic [ 31:0]            rx_st_parity_q,rx_st_parity_q1;
    logic                    rx_st_valid_q,rx_st_valid_q1;
    logic [ 2:0]             rx_st_bar_range_q,rx_st_bar_range_q1;
    logic [ 2:0]             rx_st_empty_q,rx_st_empty_q1;

    logic                    cnt_even;   /*synthesis maxfan=16 */

    logic [par_sriov? 310: only_par? 298 : only_sriov? 278 : 266:0]    rx_fifo_wrdata_lo,
                                                                       rx_fifo_wrdata_hi;
    logic [par_sriov? 310: only_par? 298 : only_sriov? 278 : 266:0]    rx_fifo_rddata_lo,
                                                                       rx_fifo_rddata_hi;
    logic                                                  rx_fifo_wrreq,
                                                           rx_fifo_rdreq;
    logic                                                  rx_fifo_empty,
                                                           rx_fifo_empty2,
                                                           rx_fifo_full;
    logic [2:0]                                            rx_fifo_rusedw;
    logic                                                  rx_fifo_rdreq_q;

    //---------------------------------------------
    //input signals flop in first to ease timing
    always_ff @ (posedge clk500)
      begin
          rx_st_sop_q    <= rx_st_sop_q1;
          rx_st_eop_q    <= rx_st_eop_q1;
          rx_st_data_q   <= rx_st_data_q1;
          rx_st_parity_q <= rx_st_parity_q1;
          rx_st_valid_q  <= rx_st_valid_q1;
          rx_st_bar_range_q <= rx_st_bar_range_q1;
          rx_st_empty_q  <= rx_st_empty_q1;

          rx_st_vf_active_q <= rx_st_vf_active_q1;
          rx_st_func_num_q  <= rx_st_func_num_q1;
          rx_st_vf_num_q    <= rx_st_vf_num_q1;

          rx_st_sop_q1    <= rx_st_sop_i;
          rx_st_eop_q1    <= rx_st_eop_i;
          rx_st_data_q1   <= rx_st_data_i;
          rx_st_parity_q1 <= rx_st_parity_i;
          rx_st_valid_q1  <= rx_st_valid_i;
          rx_st_bar_range_q1 <= rx_st_bar_range_i;
          rx_st_empty_q1  <= rx_st_empty_i;

          rx_st_vf_active_q1 <= rx_st_vf_active_i;
          rx_st_func_num_q1  <= rx_st_func_num_i;
          rx_st_vf_num_q1    <= rx_st_vf_num_i;
          if (rst) begin
                rx_st_ready   <= 1'b0;
                rx_st_ready_o <= 1'b0;
          end
          else begin
                rx_st_ready   <= rx_st_ready_i;
                rx_st_ready_o <= rx_st_ready;
          end
      end

    //rx buffer selection logic
    always_ff @ (posedge clk500)
      begin
          if (rst)
            begin
                cnt_even <= 1'b1;
            end
          else
            begin
                cnt_even <= !rx_st_valid_q ? 1'b1 : rx_st_valid_q ? ~cnt_even : cnt_even;
            end
      end

    generate
      if (par_sriov) begin
        assign rx_fifo_wrdata_hi = {rx_st_vf_active_q,rx_st_vf_num_q,rx_st_func_num_q,rx_st_bar_range_q, rx_st_empty_q, rx_st_eop_q, rx_st_sop_q, rx_st_valid_q, rx_st_parity_q, rx_st_data_q};
      end
      else if (only_par)begin
        assign rx_fifo_wrdata_hi = {rx_st_func_num_q,rx_st_bar_range_q, rx_st_empty_q, rx_st_eop_q, rx_st_sop_q, rx_st_valid_q, rx_st_parity_q, rx_st_data_q};
      end
      else if (only_sriov) begin
        assign rx_fifo_wrdata_hi = {rx_st_vf_active_q,rx_st_vf_num_q,rx_st_func_num_q,rx_st_bar_range_q, rx_st_empty_q, rx_st_eop_q, rx_st_sop_q, rx_st_valid_q, rx_st_data_q};
      end
      else begin
        assign rx_fifo_wrdata_hi = {rx_st_func_num_q,rx_st_bar_range_q, rx_st_empty_q, rx_st_eop_q, rx_st_sop_q, rx_st_valid_q, rx_st_data_q};
      end
    endgenerate


    generate
      //async FIFO write interface
      always @ (posedge clk500) begin

        if (par_sriov)begin
           rx_fifo_wrdata_lo[310:299] <= {rx_st_vf_active_q,rx_st_vf_num_q};
        end
        if (only_sriov)begin
           rx_fifo_wrdata_lo[278:267] <= {rx_st_vf_active_q,rx_st_vf_num_q};
        end

        if (par_sriov || only_par) begin
          rx_fifo_wrdata_lo[287:0]   <= {rx_st_parity_q, rx_st_data_q};
          rx_fifo_wrdata_lo[298:294] <= {rx_st_func_num_q,rx_st_bar_range_q};
          if (rst) begin
            rx_fifo_wrdata_lo[293:288] <= '0;
          end
          else begin
            rx_fifo_wrdata_lo[293:288] <= {rx_st_empty_q, rx_st_eop_q, rx_st_sop_q, 1'b1};
          end
        end
        else begin
          rx_fifo_wrdata_lo[255:0] <= rx_st_data_q;
          rx_fifo_wrdata_lo[266:262] <= {rx_st_func_num_q,rx_st_bar_range_q};
          if (rst) begin
             rx_fifo_wrdata_lo[261:256] <= '0;
           end
           else begin
             rx_fifo_wrdata_lo[261:256] <= {rx_st_empty_q, rx_st_eop_q, rx_st_sop_q, 1'b1};
           end
        end
      end // always @ (posedge clk500)
    endgenerate


     //async FIFO write interface
      always @ (posedge clk500)
      begin
        if (rst) begin
          rx_fifo_wrreq     <= 1'b0;
        end
        else begin
          rx_fifo_wrreq     <= rx_st_valid_q & cnt_even;
        end
      end // always @ (posedge clk500)

    always @ (posedge clk250)
      begin
          rx_fifo_rdreq_q <= rx_fifo_rdreq;

          if (usr_rst_clk250)
            rx_fifo_rdreq <= 1'b0;
          else
            rx_fifo_rdreq <= ~(rx_fifo_empty |rx_fifo_empty2) & ~(rx_fifo_rdreq & rx_fifo_rusedw <= 2);
            //rx_fifo_rdreq <= ~(rx_fifo_empty|rx_fifo_empty2);
      end
    //async FIFO read interface
    always @ (posedge clk250)
      begin
          rx_st_data_o  <= rx_fifo_rdreq_q? {rx_fifo_rddata_hi[255:0], rx_fifo_rddata_lo[255:0]} : 512'h0;
          rx_st_parity_o <= (pld_rx_parity_ena == "enable") ? (rx_fifo_rdreq_q? {rx_fifo_rddata_hi[287:256], rx_fifo_rddata_lo[287:256]} : 64'h0) : 64'h0;
          if (usr_rst_clk250)
            begin
                rx_st_valid_o <= '0;
                rx_st_sop_o   <= '0;
                rx_st_eop_o   <= '0;
                rx_st_bar_range_o <= '0;
                rx_st_empty_o     <= '0;
                rx_st_vf_active_o <= '0;
                rx_st_func_num_o  <= '0;
                rx_st_vf_num_o    <= '0;
            end
          else
            begin
                rx_st_valid_o      <= (par_sriov || only_par) ? (rx_fifo_rdreq_q ? {rx_fifo_rddata_hi[288],     rx_fifo_rddata_lo[288]}     : '0) : (rx_fifo_rdreq_q ? {rx_fifo_rddata_hi[256],     rx_fifo_rddata_lo[256]}     : '0);
                rx_st_sop_o        <= (par_sriov || only_par) ? (rx_fifo_rdreq_q ? {rx_fifo_rddata_hi[289],     rx_fifo_rddata_lo[289]}     : '0) : (rx_fifo_rdreq_q ? {rx_fifo_rddata_hi[257],     rx_fifo_rddata_lo[257]}     : '0);
                rx_st_eop_o        <= (par_sriov || only_par) ? (rx_fifo_rdreq_q ? {rx_fifo_rddata_hi[290],     rx_fifo_rddata_lo[290]}     : '0) : (rx_fifo_rdreq_q ? {rx_fifo_rddata_hi[258],     rx_fifo_rddata_lo[258]}     : '0);
                rx_st_empty_o      <= (par_sriov || only_par) ? (rx_fifo_rdreq_q ? {rx_fifo_rddata_hi[293:291], rx_fifo_rddata_lo[293:291]} : '0) : (rx_fifo_rdreq_q ? {rx_fifo_rddata_hi[261:259], rx_fifo_rddata_lo[261:259]} : '0);
                rx_st_bar_range_o  <= (par_sriov || only_par) ? (rx_fifo_rdreq_q ? {rx_fifo_rddata_hi[296:294], rx_fifo_rddata_lo[296:294]} : '0) : (rx_fifo_rdreq_q ? {rx_fifo_rddata_hi[264:262], rx_fifo_rddata_lo[264:262]} : '0);
                rx_st_func_num_o   <= (par_sriov || only_par) ? (rx_fifo_rdreq_q ? {rx_fifo_rddata_hi[298:297], rx_fifo_rddata_lo[298:297]} : '0) : (rx_fifo_rdreq_q ? {rx_fifo_rddata_hi[266:265], rx_fifo_rddata_lo[266:265]} : '0);
              
                
                rx_st_vf_num_o     <= (par_sriov) ? (rx_fifo_rdreq_q? {rx_fifo_rddata_hi[309:299], rx_fifo_rddata_lo[309:299]} : '0) : (only_sriov) ? (rx_fifo_rdreq_q? {rx_fifo_rddata_hi[277:267], rx_fifo_rddata_lo[277:267]} : '0) : '0 ;
                rx_st_vf_active_o  <= (par_sriov) ? (rx_fifo_rdreq_q? {rx_fifo_rddata_hi[310],     rx_fifo_rddata_lo[310]}     : '0) : (only_sriov) ? (rx_fifo_rdreq_q? {rx_fifo_rddata_hi[278],     rx_fifo_rddata_lo[278]}     : '0) : '0 ;

            end
      end // always @ (posedge clk250)
/* 
    dcfifo rx_fifo_lo
      (
       .aclr  (rst),
       .wrclk (clk500),
       .wrreq (rx_fifo_wrreq),
       .data  (rx_fifo_wrdata_lo),
       .wrusedw(),
       .wrempty(),
       .wrfull (rx_fifo_full),
       .rdclk (clk250),
       .rdreq (rx_fifo_rdreq),
       .rdfull(),
       .rdempty(rx_fifo_empty),
       .rdusedw(rx_fifo_rusedw),
       .q      (rx_fifo_rddata_lo),
       .eccstatus()
       );
    defparam
      rx_fifo_lo.add_ram_output_register  = "ON",
      rx_fifo_lo.intended_device_family  = "Stratix 10",
      rx_fifo_lo.lpm_numwords = 8,
      rx_fifo_lo.lpm_width    = (par_sriov? 311: only_par? 299 : only_sriov? 279 : 267),
      rx_fifo_lo.lpm_widthu   = 3,
      rx_fifo_lo.overflow_checking  = "OFF",
      rx_fifo_lo.underflow_checking  = "OFF",
      rx_fifo_lo.use_eab  = "ON";

    dcfifo rx_fifo_hi
      (
       .aclr  (rst),
       .wrclk (clk500),
       .wrreq (rx_fifo_wrreq),
       .data  (rx_fifo_wrdata_hi),
       .wrusedw(),
       .wrempty(),
       .wrfull (),
       .rdclk (clk250),
       .rdreq (rx_fifo_rdreq),
       .rdfull(),
       .rdempty(),
       .rdusedw(),
       .q      (rx_fifo_rddata_hi),
       .eccstatus()
       );
    defparam
      rx_fifo_hi.add_ram_output_register  = "ON",
      rx_fifo_hi.intended_device_family  = "Stratix 10",
      rx_fifo_hi.lpm_numwords = 8,
      rx_fifo_hi.lpm_width    = (par_sriov? 311: only_par? 299 : only_sriov? 279 : 267),
      rx_fifo_hi.lpm_widthu   = 3,
      rx_fifo_hi.overflow_checking  = "OFF",
      rx_fifo_hi.underflow_checking  = "OFF",
      rx_fifo_hi.use_eab  = "ON";

   */   
     
    altera_pcie_s10_gen3x16_dcfifo
      #(.FIFO_WIDTH (par_sriov? 311: only_par? 299 : only_sriov? 279 : 267),
        .ADDR_WIDTH (3),
        .SIM_EMULATE(0)
        )
      rx_fifo_lo
        (
         .din_clk  (clk500),
         .din_sclr (rst),
         .din_wreq (rx_fifo_wrreq),
         .din      (rx_fifo_wrdata_lo),
         .din_wusedw(),
         .dout_clk  (clk250),
         .dout_sclr (rst_clk250),
         .dout_rreq (rx_fifo_rdreq),
         .dout      (rx_fifo_rddata_lo),
         .dout_rusedw(rx_fifo_rusedw),
         .fifo_empty (rx_fifo_empty),
         .fifo_empty2 (rx_fifo_empty2),
         .fifo_almost_empty(),
         .fifo_almost_full ()
         );

     altera_pcie_s10_gen3x16_dcfifo
       #(.FIFO_WIDTH (par_sriov? 311: only_par? 299 : only_sriov? 279 : 267),
        .ADDR_WIDTH (3),
        .SIM_EMULATE(0)
        )
      rx_fifo_hi 
        (
         .din_clk  (clk500),
         .din_sclr (rst),
         .din_wreq (rx_fifo_wrreq),
         .din      (rx_fifo_wrdata_hi),
         .din_wusedw(),
         .dout_clk  (clk250),
         .dout_sclr (rst_clk250),
         .dout_rreq (rx_fifo_rdreq),
         .dout      (rx_fifo_rddata_hi),
         .dout_rusedw(),
         .fifo_empty (),
         .fifo_almost_empty(),
         .fifo_almost_full ()
         );

     
endmodule
