// (C) 2001-2019 Intel Corporation. All rights reserved.
// Your use of Intel Corporation's design tools, logic functions and other 
// software and tools, and its AMPP partner logic functions, and any output 
// files from any of the foregoing (including device programming or simulation 
// files), and any associated documentation or information are expressly subject 
// to the terms and conditions of the Intel Program License Subscription 
// Agreement, Intel FPGA IP License Agreement, or other applicable 
// license agreement, including, without limitation, that your use is for the 
// sole purpose of programming logic devices manufactured by Intel and sold by 
// Intel or its authorized distributors.  Please refer to the applicable 
// agreement for further details.



module sync_bit
  #(
    parameter DWIDTH = 1,    // Sync Data input
    parameter RESET_VAL = 0  // Reset value
    )
    (
    input  wire              clk,     // clock
    input  wire              rst_n,   // async reset
    input  wire [DWIDTH-1:0] din, // data in
    output wire [DWIDTH-1:0] dout // data out
     );

   // Define wires/regs
   reg [(DWIDTH)-1:0] sync_regs_s1; /* synthesis preserve */
   reg [(DWIDTH)-1:0] sync_regs_s2; /* synthesis preserve */
   //wire                         reset_value;
   
   localparam reset_value = (RESET_VAL == 1) ? 1'b1 : 1'b0;  // To eliminate truncating warning

   // Sync Always block
   always @(negedge rst_n or posedge clk) begin
      if (rst_n == 1'b0) begin
         sync_regs_s2[DWIDTH-1:0] <= {(DWIDTH){reset_value}};
      end
      else begin
         sync_regs_s2[DWIDTH-1:0] <= sync_regs_s1[(DWIDTH-1):0];
      end
   end
   
   // NF: both FF stages have reset
   always @(negedge rst_n or posedge clk) begin
      if (rst_n == 1'b0) begin
         sync_regs_s1[DWIDTH-1:0] <= {(DWIDTH){reset_value}};
      end
      else begin
         sync_regs_s1[DWIDTH-1:0] <= din;
      end
   end

   assign dout = sync_regs_s2;

endmodule 

