// (C) 2001-2019 Intel Corporation. All rights reserved.
// Your use of Intel Corporation's design tools, logic functions and other 
// software and tools, and its AMPP partner logic functions, and any output 
// files from any of the foregoing (including device programming or simulation 
// files), and any associated documentation or information are expressly subject 
// to the terms and conditions of the Intel Program License Subscription 
// Agreement, Intel FPGA IP License Agreement, or other applicable 
// license agreement, including, without limitation, that your use is for the 
// sole purpose of programming logic devices manufactured by Intel and sold by 
// Intel or its authorized distributors.  Please refer to the applicable 
// agreement for further details.


//----------------------------------------------------------------
//    Project Name:   avmm_bridge_512
//    Module Name :   intel_pcie_bri.sv
//    Author      :   
//    Description :   Bar Interpreter top file
//----------------------------------------------------------------

// synopsys translate_off
`timescale 1 ns / 1 ps
// synopsys translate_on

module intel_pcie_bri_hwtcl # (
    parameter PFNUM_WIDTH               = 2,
    parameter BRI_DATA_WIDTH            = 512, // Max of the slave data widths.
    parameter BRI_BE_WIDTH              = 64,  // Max of the slave byte enable widths.(Generally equal to Data_width/8)
    parameter BAM_ADDR_WIDTH 		    = 32 /// This address width is the max of all the address ranges of all the bars.
                                             /// For example: Bar0 access range of 2K and Bar1 access range of 4k. The BAM_ADDR_WIDTH will be 12 bits.
                                             /// This parameter will be controlled by the tcl which needs to consider this condition.
) 
(
    input logic                                        Clk_i,
    input logic                                        Rstn_i,

    // Conduit (from BAM)
    input logic [PFNUM_WIDTH-1:0]                      bri_s_pfnum_i,
    input logic [2:0]                                  bri_s_bar_i,
    
    // Slave (from BAM)
    input logic [BAM_ADDR_WIDTH-1:0]                   bri_s_address_i,
    input  logic [63:0]                                bri_s_byteenable_i,
    input  logic                                       bri_s_read_i,
    output logic [511:0]                               bri_s_readdata_o,
    output logic                                       bri_s_readdatavalid_o,
    input  logic                                       bri_s_write_i,
    input  logic [511:0]                               bri_s_writedata_i,
    input  logic [3:0]                                 bri_s_burstcount_i,
    output logic                                       bri_s_waitrequest_o,
    output logic [1:0]                                 bri_s_response_o,

    // Master (to ADM, TGC, and DMA)
    output logic [PFNUM_WIDTH+BAM_ADDR_WIDTH+3-1:0]    bri_m_address_o,
    output logic                                       bri_m_read_o,
    output logic [BRI_BE_WIDTH-1:0]                    bri_m_byteenable_o,
    input  logic [BRI_DATA_WIDTH-1:0]                  bri_m_readdata_i,
    input  logic                                       bri_m_readdatavalid_i,
    input  logic [1:0]                                 bri_m_response_i,
    output logic                                       bri_m_write_o,
    output logic [BRI_DATA_WIDTH-1:0]                  bri_m_writedata_o,
    input  logic                                       bri_m_waitrequest_i,
    output logic [3:0]                                 bri_m_burstcount_o
);

assign bri_m_address_o          = {bri_s_pfnum_i,bri_s_bar_i,bri_s_address_i};
assign bri_m_read_o             = bri_s_read_i;
assign bri_m_write_o            = bri_s_write_i;
assign bri_m_writedata_o        = bri_s_writedata_i;
assign bri_m_byteenable_o       = bri_s_byteenable_i;
assign bri_s_readdata_o         = bri_m_readdata_i;
assign bri_s_readdatavalid_o    = bri_m_readdatavalid_i;
assign bri_s_response_o         = bri_m_response_i;
assign bri_s_waitrequest_o      = bri_m_waitrequest_i;
assign bri_m_burstcount_o       = bri_s_burstcount_i;   
endmodule

